@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames.py
-Version : 1.5.2
+Version : 1.5.3
 Author  : Stefano Covino
-Date    : 22/01/2012
+Date    : 19/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -31,6 +31,7 @@ History : (27/09/2010) First version.
         : (26/08/2011) Consistency check for unreliable CRVAL1,2 and CDELT1,2.
         : (04/11/2011) More flexibility in header coordinate format.
         : (22/01/2012) Check that at least one catalogue returns data.
+        : (19/08/2013) Data saved with the original format.
 """
 
 
@@ -434,6 +435,16 @@ class Astrometry:
         frm[0].header = self.FitsFrame.Header
         warnings.resetwarnings()
         warnings.filterwarnings('ignore', category=UserWarning, append=True)
+        if self.FitsFrame.BITPIX == 8:
+            frm[0].scale('uint8')
+        elif self.FitsFrame.BITPIX == 16:
+            frm[0].scale('int16') 
+        elif self.FitsFrame.BITPIX == 32:
+            frm[0].scale('int32')
+        elif self.FitsFrame.BITPIX == -32:
+            frm[0].scale('float32')
+        elif self.FitsFrame.BITPIX == -64:
+            frm[0].scale('float64')
         frm.writeto(nfile,clobber=True)
         warnings.resetwarnings() 
         warnings.filterwarnings('always', category=UserWarning, append=True)
