@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.18
+Version : 1.1.23
 Author  : Stefano Covino
-Date    : 12/08/2013
+Date    : 24/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -48,7 +48,7 @@ History : (28/09/2010) First named version.
         : (13/09/2011) V. 3.10.1b1.
         : (22/09/2011) V. 3.10.1b2 and no more SRPPipelines.
         : (29/09/2011) V. 3.10.1b3 and new filters.
-        : (02/10/2011) V. 3.10.1b4, genera function for list of FITS files.
+        : (02/10/2011) V. 3.10.1b4, general function for list of FITS files.
         : (11/10/2011) V. 3.10.1.
         : (12/10/2011) V. 3.10.2b1.
         : (23/10/2011) V. 3.10.2b2.
@@ -97,6 +97,10 @@ History : (28/09/2010) First named version.
         : (26/07/2013) APASS catalogue and V. 3.10.10.b3.
         : (29/07/2013) GetTabEntry returns not identified objects too and V. 3.10.10.b4.
         : (12/08/2013) V. 3.10.10.
+        : (13/08/2013) V. 3.10.11b1.
+        : (18/08/2013) V. 3.10.11b2.
+        : (19/08/2013) V. 3.10.11b3 and b4.
+        : (24/08/2013) V. 3.10.11.
 """
 
 
@@ -111,5 +115,5 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.10.10'
+__version__ = '3.10.11'
 
